@@ -4,10 +4,10 @@ use crate::style::ShapeStyle;
 /// The point plot object, which takes an iterator of points in guest coordinate system
 /// and create an element for each point
 pub struct PointSeries<'a, Coord, I: IntoIterator<Item = Coord>, E> {
-    style: ShapeStyle<'a>,
+    style: ShapeStyle,
     size: u32,
     data_iter: I::IntoIter,
-    make_point: &'a dyn Fn(Coord, u32, ShapeStyle<'a>) -> E,
+    make_point: &'a dyn Fn(Coord, u32, ShapeStyle) -> E,
 }
 
 impl<'a, Coord, I: IntoIterator<Item = Coord>, E> Iterator for PointSeries<'a, Coord, I, E> {
@@ -21,12 +21,12 @@ impl<'a, Coord, I: IntoIterator<Item = Coord>, E> Iterator for PointSeries<'a, C
 
 impl<'a, Coord, I: IntoIterator<Item = Coord>, E> PointSeries<'a, Coord, I, E>
 where
-    E: PointElement<'a, Coord>,
+    E: PointElement<Coord>,
 {
     /// Create a new point series with the element that implements point trait.
     /// You may also use a more general way to create a point series with `of_element`
     /// function which allows a cusmotized element construction function
-    pub fn new<S: Into<ShapeStyle<'a>>>(iter: I, size: u32, style: S) -> Self {
+    pub fn new<S: Into<ShapeStyle>>(iter: I, size: u32, style: S) -> Self {
         Self {
             data_iter: iter.into_iter(),
             size,
@@ -40,7 +40,7 @@ impl<'a, Coord, I: IntoIterator<Item = Coord>, E> PointSeries<'a, Coord, I, E> {
     /// Create a new point series. Similar to `PointSeries::new` but it doesn't
     /// requires the element implements point trait. So instead of using the point
     /// constructor, it uses the cusmotized function for element creation
-    pub fn of_element<S: Into<ShapeStyle<'a>>, F: Fn(Coord, u32, ShapeStyle<'a>) -> E>(
+    pub fn of_element<S: Into<ShapeStyle>, F: Fn(Coord, u32, ShapeStyle) -> E>(
         iter: I,
         size: u32,
         style: S,
